<?php
/**
 * Plugin Name: Magic Export & Import
 * Description: The ultimate tool to migrate any content including posts, terms, users, comments, WooCommerce shop orders and ACF Options pages.
 * Version: 1.0.2
 * Requires at least: 6.2
 * Requires PHP: 7.4
 * Author: Kovalskyi Roman (UA)
 * Author URI: https://t.me/kovalchik
 * Author Email: kovalchik888@gmail.com
 * Text Domain: magic-export-import
 * Domain Path: /languages/
 * License: GPL v3 or later
 * License URI: https://www.gnu.org/licenses/gpl-3.0.txt
 *
 * @package Magic_Export_Import
 */

defined( 'ABSPATH' ) || exit;
defined( 'MAGIC_EX_IM_FILE' ) || define( 'MAGIC_EX_IM_FILE', __FILE__ );
defined( 'MAGIC_EX_IM_ABSPATH' ) || define( 'MAGIC_EX_IM_ABSPATH', dirname( MAGIC_EX_IM_FILE ) . '/' );
defined( 'MAGIC_EX_IM_CACHE_KEY' ) || define( 'MAGIC_EX_IM_CACHE_KEY', 'magic_ex_im_cache' );

require_once MAGIC_EX_IM_ABSPATH . 'includes/trait-magic-ex-im-singleton.php';

/**
 * Singleton class to manage plugin setup.
 */
class Magic_EX_IM_Setup {

	use Magic_EX_IM_Singleton;

	/**
	 * Class constructor.
	 */
	protected function __construct() {
		add_action( 'init', array( $this, 'init' ), 99 );
		add_filter( 'plugin_action_links_' . plugin_basename( MAGIC_EX_IM_FILE ), array( $this, 'plugin_action_links' ) );
	}

	/**
	 * Processes dynamic filter hook 'plugin_action_links_' . plugin_basename( MAGIC_EX_IM_FILE ).
	 *
	 * @param array $links Existing links.
	 * @return array
	 */
	public function plugin_action_links( $links ) {

		$settings_url = get_admin_url( null, 'admin.php?page=magic-export-import-posts' );
		$links[]      = sprintf( '<a href="%s">%s</a>', esc_url( $settings_url ), 'Start Magic' );

		return array_reverse( $links );
	}

	/**
	 * Processes action hook 'init'.
	 */
	public function init() {

		// Core.
		include_once MAGIC_EX_IM_ABSPATH . 'includes/magic-ex-im-fallback-functions.php';
		include_once MAGIC_EX_IM_ABSPATH . 'includes/magic-ex-im-functions.php';
		include_once MAGIC_EX_IM_ABSPATH . 'includes/class-magic-ex-im-data.php';
		include_once MAGIC_EX_IM_ABSPATH . 'includes/class-magic-ex-im-type.php';

		// Export / Import types.
		include_once MAGIC_EX_IM_ABSPATH . 'includes/magic-types/class-magic-ex-im-type-posts.php';
		include_once MAGIC_EX_IM_ABSPATH . 'includes/magic-types/class-magic-ex-im-type-terms.php';
		include_once MAGIC_EX_IM_ABSPATH . 'includes/magic-types/class-magic-ex-im-type-users.php';
		include_once MAGIC_EX_IM_ABSPATH . 'includes/magic-types/class-magic-ex-im-type-comments.php';
		include_once MAGIC_EX_IM_ABSPATH . 'includes/magic-types/class-magic-ex-im-type-shop-orders.php';
		include_once MAGIC_EX_IM_ABSPATH . 'includes/magic-types/class-magic-ex-im-type-acf-options-pages.php';

		// Plugin adapters.
		include_once MAGIC_EX_IM_ABSPATH . 'includes/plugin-adapters/class-magic-ex-im-adapter-polylang.php';
		include_once MAGIC_EX_IM_ABSPATH . 'includes/plugin-adapters/class-magic-ex-im-adapter-woocommerce.php';
		include_once MAGIC_EX_IM_ABSPATH . 'includes/plugin-adapters/class-magic-ex-im-adapter-acf.php';
		include_once MAGIC_EX_IM_ABSPATH . 'includes/plugin-adapters/class-magic-ex-im-adapter-yoast-seo.php';
		include_once MAGIC_EX_IM_ABSPATH . 'includes/plugin-adapters/class-magic-ex-im-adapter-wc-bexio-automator.php';
		include_once MAGIC_EX_IM_ABSPATH . 'includes/plugin-adapters/class-magic-ex-im-adapter-cf7.php';
	}
}

Magic_EX_IM_Setup::instance();
