<?php
/**
 * Class Magic_EX_IM_Adapter_CF7.
 *
 * @package Magic_Export_Import\Plugin_Adapter
 */

defined( 'ABSPATH' ) || exit;

/**
 * Singleton class to provide 'Contact Form 7' plugin support.
 */
class Magic_EX_IM_Adapter_CF7 {

	/**
	 * Constructor.
	 */
	public function __construct() {

		if ( class_exists( 'WPCF7' ) ) {
			add_action( 'magic_ex_im_init', array( $this, 'magic_ex_im_init' ) );
		}
	}

	/**
	 * Processes action hook 'magic_ex_im_init'.
	 */
	public function magic_ex_im_init() {
		add_filter( 'magic_im_item_data_before_update', array( $this, 'magic_im_item_data_before_update' ) );
	}

	/**
	 * Processes filter hook 'magic_im_item_data_before_update'.
	 *
	 * @param array $item_data Processing post data grouped by keys.
	 * @return array
	 */
	public function magic_im_item_data_before_update( $item_data ) {

		if ( 'posts:wpcf7_contact_form' !== magic_ex_im_get_magic()
			|| ! function_exists( 'wpcf7_generate_contact_form_hash' )
			|| ! function_exists( 'wpcf7_get_contact_form_by_hash' ) ) {

			return $item_data;
		}

		// Assign contact form with a unique hash if not yet.

		$item_id = magic_ex_im_get_item_id();
		$hash    = $item_data['meta']['_hash'] ?? '';

		if ( magic_im_is_new_item() ) {

			if ( ! $hash ) {
				$hash = wpcf7_generate_contact_form_hash( $item_id );

			} else {
				$existing_form = wpcf7_get_contact_form_by_hash( $hash );

				if ( $existing_form ) {
					$hash = wpcf7_generate_contact_form_hash( $item_id );
				}
			}
		} else {

			$existing_hash = get_post_meta( $item_id, '_hash', true );

			if ( $existing_hash ) {
				$hash = $existing_hash;

			} elseif ( ! $hash ) {
				$hash = wpcf7_generate_contact_form_hash( $item_id );

			} else {
				$existing_form = wpcf7_get_contact_form_by_hash( $hash );

				if ( $existing_form ) {
					$hash = wpcf7_generate_contact_form_hash( $item_id );
				}
			}
		}

		$item_data['meta']['_hash'] = $hash;

		return $item_data;
	}
}

return new Magic_EX_IM_Adapter_CF7();
