<?php
/**
 * Class Magic_EX_IM_Adapter_WC_Bexio_Automator.
 *
 * @package Magic_Export_Import\Plugin_Adapter
 */

defined( 'ABSPATH' ) || exit;

/**
 * Singleton class to provide 'WooCommerce Bexio Automator' plugin support.
 */
class Magic_EX_IM_Adapter_WC_Bexio_Automator {

	const META_KEY = 'bexio_account_product';

	/**
	 * Constructor.
	 */
	public function __construct() {
		add_action( 'magic_ex_im_init', array( $this, 'magic_ex_im_init' ) );
	}

	/**
	 * Processes action hook 'magic_ex_im_init'.
	 */
	public function magic_ex_im_init() {
		add_filter( 'magic_ex_get_key_data', array( $this, 'magic_ex_get_key_data' ), 10, 3 );
		add_filter( 'magic_im_item_data_before_update', array( $this, 'magic_im_item_data_before_update' ) );
	}

	/**
	 * Processes filter hook 'magic_ex_get_key_data';
	 *
	 * @param mixed  $key_data Current key data.
	 * @param string $key Data key.
	 * @param string $group Data key Group.
	 * @return mixed
	 */
	public function magic_ex_get_key_data( $key_data, $key, $group ) {

		// Convert Bexio account ID into name.
		if ( 'meta' === $group && self::META_KEY === $key
			&& is_callable( array( '\Raptus\WC\BexioConnector\Data', 'get_accounts' ) ) ) {

			$bexio_account_id = $key_data;

			if ( is_numeric( $bexio_account_id ) ) {

				$bexio_accounts      = \Raptus\WC\BexioConnector\Data::get_accounts();
				$bexio_account_index = array_search( intval( $bexio_account_id ), array_column( $bexio_accounts, 'id' ), true );

				$key_data = $bexio_accounts[ $bexio_account_index ]['name'] ?? '';
			}
		}

		return $key_data;
	}

	/**
	 * Processes filter hook 'magic_im_item_data_before_update'.
	 *
	 * @param array $item_data Importing item data grouped by type.
	 * @return array
	 */
	public function magic_im_item_data_before_update( $item_data ) {

		// Convert Bexio account name into ID, set empty string if Bexio account is not found.
		if ( $item_data['meta'][ self::META_KEY ] ?? '' ) {

			if ( ! is_callable( array( '\Raptus\WC\BexioConnector\Data', 'get_accounts' ) ) ) {
				unset( $item_data['meta'][ self::META_KEY ] ); // Remove importing value if plugin isn't active.

			} else {
				$bexio_account_name = $item_data['meta'][ self::META_KEY ];

				if ( ! is_numeric( $bexio_account_name ) ) {
					$bexio_accounts      = \Raptus\WC\BexioConnector\Data::get_accounts();
					$bexio_account_index = array_search( $bexio_account_name, array_column( $bexio_accounts, 'name' ), true );

					$item_data['meta'][ self::META_KEY ] = $bexio_accounts[ $bexio_account_index ]['id'] ?? '';
				}
			}
		}

		return $item_data;
	}
}

return new Magic_EX_IM_Adapter_WC_Bexio_Automator();
