<?php
/**
 * Comments export advanced filters.
 *
 * @package Magic_Export_Import\Comments
 */

defined( 'ABSPATH' ) || exit;

$all_comments = $args['magic_items'];

$comment_types    = array();
$comment_statuses = array();
$comment_dates    = array(
	'min' => '',
	'max' => '',
);

// Grab all comments types, statuses, min and max date.
foreach ( $all_comments as $comment_id ) {

	$comment_obj = get_comment( $comment_id );

	if ( ! $comment_obj ) {
		continue;
	}

	$comm_type = $comment_obj->comment_type;

	// Get comment status compatible with get_comment_statuses() array keys,
	// function wp_get_comment_status() is suddenly not compatible.
	switch ( $comment_obj->comment_approved ) {
		case '1':
			$comm_status = 'approve';
			break;
		case '0':
			$comm_status = 'hold';
			break;
		case 'spam':
			$comm_status = 'spam';
			break;
		case 'trash':
			$comm_status = 'trash';
			break;
		default:
			$comm_status = false;
	}

	$comm_date_stamp = strtotime( $comment_obj->comment_date );

	if ( $comm_type && ! in_array( $comm_type, $comment_types, true ) ) {
		$comment_types[] = $comm_type;
	}

	if ( $comm_status && ! in_array( $comm_status, $comment_statuses, true ) ) {
		$comment_statuses[] = $comm_status;
	}

	if ( ! $comment_dates['min'] || $comm_date_stamp < $comment_dates['min'] ) {
		$comment_dates['min'] = $comm_date_stamp;
	}

	if ( ! $comment_dates['max'] || $comm_date_stamp > $comment_dates['max'] ) {
		$comment_dates['max'] = $comm_date_stamp;
	}
}

// Ignore time in comments dates.
foreach ( $comment_dates as $key => $comm_date_stamp ) {
	$comment_dates[ $key ] = wp_date( 'Y-m-d', $comm_date_stamp );
} ?>

<?php $checked_disabled = count( $comment_types ) === 1; ?>

<div class="magic-ex-advanced-filter-type">
	<input type="checkbox" name="magic-ex-by-comment-types" id="magic-ex-by-comment-types">
	<label for="magic-ex-by-comment-types">Comment Type</label>
</div>

<div class="magic-ex-checkboxes-wrapper">
	<?php
	foreach ( $comment_types as $comm_type ) :
		$field_id = 'comm_type_' . $comm_type;
		?>
	<div class="magic-ex-im-checkbox">
		<?php
		printf(
			'<input %s type="checkbox" name="magic-ex-comment-types[]" id="%s" value="%s" %s>',
			$checked_disabled ? 'class="disabled"' : '',
			esc_attr( $field_id ),
			esc_attr( $comm_type ),
			checked( $checked_disabled, true, false ),
		);
		?>
		<label for="<?php echo esc_attr( $field_id ); ?>">
			<?php echo esc_html( ucfirst( $comm_type ) ); ?>
		</label>
	</div>
	<?php endforeach; ?>
</div>

<?php $checked_disabled = count( $comment_statuses ) === 1; ?>

<div class="magic-ex-advanced-filter-type">
	<input type="checkbox" name="magic-ex-by-comment-statuses" id="magic-ex-by-comment-statuses">
	<label for="magic-ex-by-comment-statuses">Comment Status</label>
</div>

<div class="magic-ex-checkboxes-wrapper">
	<?php
	foreach ( $comment_statuses as $comm_status ) :
		$field_id = 'comm_status_' . $comm_status;
		?>
	<div class="magic-ex-im-checkbox">
		<?php
		printf(
			'<input %s type="checkbox" name="magic-ex-comment-statuses[]" id="%s" value="%s" %s>',
			$checked_disabled ? 'class="disabled"' : '',
			esc_attr( $field_id ),
			esc_attr( $comm_status ),
			checked( $checked_disabled, true, false ),
		);
		?>
		<label for="<?php echo esc_attr( $field_id ); ?>">
			<?php echo esc_html( get_comment_statuses()[ $comm_status ] ?? $comm_status ); ?>
		</label>
	</div>
	<?php endforeach; ?>
</div>

<div class="magic-ex-advanced-filter-type">
	<input type="checkbox" name="magic-ex-by-date" id="magic-ex-by-date">
	<label for="magic-ex-by-date">Comment Date</label>
</div>

<div id="magic-ex-date-wrapper">
	<label for="magic-ex-date-from">From</label>
	<input type="date" name="magic-ex-date-from" id="magic-ex-date-from"
		min="<?php echo esc_attr( $comment_dates['min'] ); ?>" max="<?php echo esc_attr( $comment_dates['max'] ); ?>"
		value="<?php echo esc_attr( $comment_dates['min'] ); ?>">
	<label for="magic-ex-date-to">To</label>
	<input type="date" name="magic-ex-date-to" id="magic-ex-date-to"
		min="<?php echo esc_attr( $comment_dates['min'] ); ?>" max="<?php echo esc_attr( $comment_dates['max'] ); ?>"
		value="<?php echo esc_attr( $comment_dates['max'] ); ?>">
</div>
