<?php
/**
 * Posts export form advanced filters.
 *
 * @package Magic_Export_Import\Posts
 *
 * phpcs:disable WordPress.DB.DirectDatabaseQuery
 */

defined( 'ABSPATH' ) || exit;

$magic_item        = magic_ex_im_get_magic_item();
$magic_items_count = $args['magic_items_count'];
$magic_item_labels = $args['magic_item_labels'];

$post_type_statuses = $wpdb->get_col(
	$wpdb->prepare(
		"SELECT DISTINCT(post_status) FROM $wpdb->posts WHERE post_type = %s",
		$magic_item
	)
);

$post_type_statuses = array_intersect( $post_type_statuses, magic_ex_im_get_post_statuses() );

$post_type_dates = $wpdb->get_row(
	$wpdb->prepare(
		"SELECT DATE(MIN(post_date)) AS min, DATE(MAX(post_date)) AS max
		FROM $wpdb->posts
		WHERE post_type = %s",
		$magic_item
	),
	ARRAY_A
);

$post_type_taxonomies = get_object_taxonomies( $magic_item );
$post_type_terms      = array();

foreach ( $post_type_taxonomies as $post_tax ) {

	$terms = apply_filters(
		'magic_ex_posts_advanced_filter_terms',
		get_terms( array( 'taxonomy' => $post_tax ) ),
		$post_tax
	);

	if ( $terms ) {
		$post_type_terms[ $post_tax ] = $terms;
	}
} ?>

<div class="magic-ex-advanced-filter-type">
	<input type="checkbox" name="magic-ex-by-parts" id="magic-ex-by-parts">
	<label for="magic-ex-by-parts">Partial export</label>
</div>

<div id="magic-ex-partial-wrapper">
	<label>Export</label>
	<input type="number" name="magic-ex-cnt" id="magic-ex-cnt" min="1" max="<?php echo intval( $magic_items_count ); ?>"
		placeholder="0" value="1">
	<label>newest item(s), skipping</label>
	<input type="number" name="magic-ex-offset" id="magic-ex-offset" min="0"
		max="<?php echo intval( $magic_items_count - 1 ); ?>" placeholder="0">
	<label>item(s)</label>
</div>

<div class="magic-ex-advanced-filter-type">
	<input type="checkbox" name="magic-ex-by-date" id="magic-ex-by-date">
	<label for="magic-ex-by-date">Date created</label>
</div>

<div id="magic-ex-date-wrapper">
	<label for="magic-ex-date-from">From</label>
	<input type="date" name="magic-ex-date-from" id="magic-ex-date-from"
		min="<?php echo esc_attr( $post_type_dates['min'] ); ?>"
		max="<?php echo esc_attr( $post_type_dates['max'] ); ?>"
		value="<?php echo esc_attr( $post_type_dates['min'] ); ?>">
	<label for="magic-ex-date-to">To</label>
	<input type="date" name="magic-ex-date-to" id="magic-ex-date-to"
		min="<?php echo esc_attr( $post_type_dates['min'] ); ?>"
		max="<?php echo esc_attr( $post_type_dates['max'] ); ?>"
		value="<?php echo esc_attr( $post_type_dates['max'] ); ?>">
</div>

<?php
if ( $post_type_statuses ) :
	$checked_disabled = count( $post_type_statuses ) === 1;
	?>

<div class="magic-ex-advanced-filter-type">
	<input type="checkbox" name="magic-ex-by-statuses" id="magic-ex-by-statuses">
	<label for="magic-ex-by-statuses">Post status</label>
</div>

<div class="magic-ex-checkboxes-wrapper">
	<?php
	foreach ( $post_type_statuses as $status_name ) :
		$field_id = 'post_status_' . $status_name;
		?>
	<div class="magic-ex-im-checkbox">
		<?php
		printf(
			'<input %s type="checkbox" name="magic-ex-statuses[]" id="%s" value="%s" %s>',
			$checked_disabled ? 'class="disabled"' : '',
			esc_attr( $field_id ),
			esc_attr( $status_name ),
			checked( $checked_disabled, true, false ),
		);
		?>
		<label for="<?php echo esc_attr( $field_id ); ?>">
			<?php echo esc_html( get_post_statuses()[ $status_name ] ?? $status_name ); ?>
		</label>
	</div>
	<?php endforeach; ?>
</div>

<?php endif; ?>

<?php if ( $post_type_terms ) : ?>

<div class="magic-ex-advanced-filter-type">
	<input type="checkbox" name="magic-ex-by-taxonomy" id="magic-ex-by-taxonomy">
	<label for="magic-ex-by-taxonomy">Taxonomies</label>
	<span class="dashicons dashicons-arrow-down" style="font-size:1.5em;"></span>
</div>

<div class="magic-ex-taxes-wrapper" style="display:none;">

	<?php
	foreach ( $post_type_terms as $post_tax => $terms ) :
		$tax_label = 'language' === $post_tax ? 'Languages' : get_taxonomy( $post_tax )->label;
		?>

	<h4><?php echo '– ' . esc_html( $tax_label ); ?></h4>

	<div class="magic-ex-checkboxes-wrapper">
		<?php
		foreach ( $terms as $term_obj ) :
			$field_id = $post_tax . '_' . $term_obj->term_id;
			?>
		<div class="magic-ex-im-checkbox">
			<input type="checkbox" name='<?php printf( 'magic-ex-taxonomy[%s][]', esc_attr( $post_tax ) ); ?>'
				id="<?php echo esc_attr( $field_id ); ?>" value="<?php echo esc_attr( $term_obj->term_id ); ?>">
			<label for="<?php echo esc_attr( $field_id ); ?>" title="<?php echo esc_attr( $term_obj->slug ); ?>">
				<?php echo esc_html( $term_obj->name ); ?>
			</label>
		</div>

		<?php endforeach; ?>
	</div>

	<?php endforeach; ?>
</div>

<?php endif; ?>
