<?php
/**
 * Shop orders export form advanced filters.
 *
 * @package Magic_Export_Import\Posts
 *
 * phpcs:disable WordPress.DB.DirectDatabaseQuery
 */

defined( 'ABSPATH' ) || exit;

$magic_items_count = $args['magic_items_count'];
$magic_item_labels = $args['magic_item_labels'];

$order_statuses = $wpdb->get_col(
	"SELECT DISTINCT(status) FROM {$wpdb->prefix}wc_orders 
	WHERE status != 'auto-draft'"
);

$order_dates = $wpdb->get_row(
	"SELECT DATE(MIN(date_created_gmt)) AS min, DATE(MAX(date_created_gmt)) AS max
	FROM {$wpdb->prefix}wc_orders",
	ARRAY_A
);
?>

<div class="magic-ex-advanced-filter-type">
	<input type="checkbox" name="magic-ex-by-parts" id="magic-ex-by-parts">
	<label for="magic-ex-by-parts">Partial export</label>
</div>

<div id="magic-ex-partial-wrapper">
	<label>Export</label>
	<input type="number" name="magic-ex-cnt" id="magic-ex-cnt" min="1" max="<?php echo intval( $magic_items_count ); ?>"
		placeholder="0" value="1">
	<label>newest <?php echo esc_html( $magic_item_labels->singular_name ); ?>(s), skipping</label>
	<input type="number" name="magic-ex-offset" id="magic-ex-offset" min="0"
		max="<?php echo intval( $magic_items_count - 1 ); ?>" placeholder="0">
	<label><?php echo esc_html( $magic_item_labels->singular_name ); ?>(s)</label>
</div>

<div class="magic-ex-advanced-filter-type">
	<input type="checkbox" name="magic-ex-by-date" id="magic-ex-by-date">
	<label for="magic-ex-by-date">Date created</label>
</div>

<div id="magic-ex-date-wrapper">
	<label for="magic-ex-date-from">From</label>
	<input type="date" name="magic-ex-date-from" id="magic-ex-date-from"
		min="<?php echo esc_attr( $order_dates['min'] ); ?>" max="<?php echo esc_attr( $order_dates['max'] ); ?>"
		value="<?php echo esc_attr( $order_dates['min'] ); ?>">
	<label for="magic-ex-date-to">To</label>
	<input type="date" name="magic-ex-date-to" id="magic-ex-date-to"
		min="<?php echo esc_attr( $order_dates['min'] ); ?>" max="<?php echo esc_attr( $order_dates['max'] ); ?>"
		value="<?php echo esc_attr( $order_dates['max'] ); ?>">
</div>

<?php
if ( $order_statuses ) :
	$checked_disabled = count( $order_statuses ) === 1;
	?>

<div class="magic-ex-advanced-filter-type">
	<input type="checkbox" name="magic-ex-by-statuses" id="magic-ex-by-statuses">
	<label for="magic-ex-by-statuses">Order status</label>
</div>

<div class="magic-ex-checkboxes-wrapper">
	<?php
	foreach ( $order_statuses as $status_name ) :
		$field_id = 'order_status_' . $status_name;
		?>
	<div class="magic-ex-im-checkbox">
		<?php
		printf(
			'<input %s type="checkbox" name="magic-ex-statuses[]" id="%s" value="%s" %s>',
			$checked_disabled ? 'class="disabled"' : '',
			esc_attr( $field_id ),
			esc_attr( $status_name ),
			checked( $checked_disabled, true, false ),
		);
		?>
		<label for="<?php echo esc_attr( $field_id ); ?>">
			<?php echo esc_html( wc_get_order_statuses()[ $status_name ] ?? $status_name ); ?>
		</label>
	</div>
	<?php endforeach; ?>
</div>

<?php endif; ?>
