<?php
/**
 * Users export advanced filters.
 *
 * @package Magic_Export_Import\Users
 *
 * phpcs:disable WordPress.DB.DirectDatabaseQuery
 */

defined( 'ABSPATH' ) || exit;

global $wpdb;
global $wp_roles;

$users_capabilities = $wpdb->get_col(
	"SELECT DISTINCT meta_value 
    FROM $wpdb->usermeta 
    WHERE meta_key = '{$wpdb->prefix}capabilities'"
);

$users_registered_dates = $wpdb->get_row(
	"SELECT DATE(MIN(user_registered)) AS min, DATE(MAX(user_registered)) AS max FROM $wpdb->users",
	ARRAY_A
);

$user_roles = array();

foreach ( $users_capabilities as $user_capability ) {
	$roles = maybe_unserialize( $user_capability );

	if ( is_array( $roles ) ) {
		foreach ( $roles as $user_role => $value ) {

			if ( ! in_array( $user_role, $user_roles, true ) ) {
				$user_roles[] = $user_role;
			}
		}
	}
} ?>

<?php $checked_disabled = count( $user_roles ) === 1; ?>

<div class="magic-ex-advanced-filter-type">
	<input type="checkbox" name="magic-ex-by-roles" id="magic-ex-by-roles">
	<label for="magic-ex-by-roles">Roles</label>
</div>

<div class="magic-ex-checkboxes-wrapper">
	<?php
	foreach ( $user_roles as $user_role ) :
		$field_id = 'user_role_' . $user_role;
		?>
	<div class="magic-ex-im-checkbox">
		<?php
		printf(
			'<input %s type="checkbox" name="magic-ex-roles[]" id="%s" value="%s" %s>',
			$checked_disabled ? 'class="disabled"' : '',
			esc_attr( $field_id ),
			esc_attr( $user_role ),
			checked( $checked_disabled, true, false ),
		);
		?>
		<label for="<?php echo esc_attr( $field_id ); ?>">
			<?php echo esc_html( $wp_roles->roles[ $user_role ]['name'] ?? ucfirst( $user_role ) ); ?>
		</label>
	</div>
	<?php endforeach; ?>
</div>

<div class="magic-ex-advanced-filter-type">
	<input type="checkbox" name="magic-ex-by-date" id="magic-ex-by-date">
	<label for="magic-ex-by-date">Date registered</label>
</div>

<div id="magic-ex-date-wrapper">
	<label for="magic-ex-date-from">From</label>
	<input type="date" name="magic-ex-date-from" id="magic-ex-date-from"
		min="<?php echo esc_attr( $users_registered_dates['min'] ); ?>"
		max="<?php echo esc_attr( $users_registered_dates['max'] ); ?>"
		value="<?php echo esc_attr( $users_registered_dates['min'] ); ?>">
	<label for="magic-ex-date-to">To</label>
	<input type="date" name="magic-ex-date-to" id="magic-ex-date-to"
		min="<?php echo esc_attr( $users_registered_dates['min'] ); ?>"
		max="<?php echo esc_attr( $users_registered_dates['max'] ); ?>"
		value="<?php echo esc_attr( $users_registered_dates['max'] ); ?>">
</div>
