<?php
/**
 * Export & Import forms.
 *
 * @package Magic_Export_Import
 */

defined( 'ABSPATH' ) || exit;

$magic_item              = magic_ex_im_get_magic_item();
$magic_items_count       = $args['magic_items_count'];
$magic_item_labels       = $args['magic_item_labels'];
$magic_item_grouped_keys = $args['magic_item_grouped_keys'];
$mandatory_keys          = $args['mandatory_keys'];
$allowed_magic_items     = $args['allowed_magic_items'];
$export_file             = $args['export_file'];
$allow_to_update_items   = $args['allow_to_update_items'];
$allow_to_create_items   = $args['allow_to_create_items'];

$filtering_key_groups = array();

// Remove group from filtering checkboxes if all its keys are mandatory.
foreach ( $magic_item_grouped_keys as $group => $keys ) {
	if ( array_intersect( $keys, $mandatory_keys ) !== $keys ) {
		$filtering_key_groups[] = $group;
	}
}
?>

<div id="magic-ex-im" class="wrap">
	<h1><?php echo esc_html( get_admin_page_title() ); ?></h1>

	<?php if ( count( $allowed_magic_items ) > 1 ) : ?>

	<div class="form-field">
		<label for="magic-ex-im-post-type">
			<h2>Type</h2>
		</label>
		<select name="magic-ex-im-post-type" id="magic-ex-im-post-type-select">
			<?php
			foreach ( $allowed_magic_items as $item_name => $item_obj ) {
				printf(
					'<option value="%1$s" %2$s>%3$s</option>',
					esc_attr( $item_name ),
					selected( $item_name === $magic_item ),
					esc_html( $item_obj->label ),
				);
			}
			?>
		</select>
	</div>

	<?php endif; ?>

	<div class="magic-ex-im-wrapper">

		<?php if ( $magic_items_count > 0 ) : ?>

		<div class="magic-ex-wrapper">
			<h2>Export <?php echo esc_html( $magic_item_labels->name ); ?></h2>

			<?php
			if ( file_exists( $export_file['path'] ) ) {
				$file_time = filemtime( $export_file['path'] );

				printf(
					'<p>Last %s export generated on <b>%s</b> at <b>%s</b> <a download href="%s">Download</a></p>',
					esc_html( $magic_item_labels->name ),
					esc_html( wp_date( 'd.m.Y', $file_time ) ),
					esc_html( wp_date( 'H:i', $file_time ) ),
					esc_url( $export_file['url'] . '?ver=' . $file_time ),
				);
			}

			printf(
				'<div id="magic-ex-items-cnt-wrapper">
					<h4>%s ready for export: <span id="magic-ex-items-cnt">%d</span></h4>
				</div>',
				esc_html( $magic_item_labels->name ),
				intval( $magic_items_count )
			);
			?>

			<div class="form-wrap">
				<form id="magic-ex-form" method="post">

					<div class="form-field">
						<label for="magic-ex-items-select">
							<?php
							echo esc_html(
								apply_filters(
									'magic_ex_individual_items_title',
									'Individual ' . $magic_item_labels->name,
								)
							);
							?>
						</label>
						<select id="magic-ex-items-select" multiple="multiple" name="magic-ex-items[]"></select>
					</div>

					<div class="form-field">
						<h4 style="margin-bottom:1em;">
							<?php echo esc_html( $magic_item_labels->name ); ?> data for export:
						</h4>
						<div id="magic-ex-keys-filters">

							<?php if ( count( $filtering_key_groups ) > 1 ) : ?>

							<div id="magic-ex-keys-by-group-wrapper">
								<label style="margin-right: 15px;">Select by group:</label>
								<div id="magic-ex-keys-by-group">
									<?php foreach ( $filtering_key_groups as $group ) : ?>
									<div class="magic-ex-im-checkbox">
										<input class="magic-ex-group"
											id="magic-ex-group-<?php echo esc_attr( $group ); ?>" type="checkbox"
											value="<?php echo esc_attr( $group ); ?>" checked>
										<label for="magic-ex-group-<?php echo esc_attr( $group ); ?>">
											<?php echo esc_html( $group ); ?>
										</label>
									</div>
									<?php endforeach; ?>

								</div>
							</div>
							<?php endif; ?>

							<div class="magic-ex-im-checkbox">
								<input id="magic-ex-all-keys-checkbox" type="checkbox" checked>
								<label for="magic-ex-all-keys-checkbox">Select All</label>
							</div>
						</div>
						<?php load_template( MAGIC_EX_IM_ABSPATH . 'template-parts/select-export-keys.php', false, $args ); ?>
					</div>

					<?php if ( isset( $magic_item_grouped_keys['meta'] ) && $magic_item_grouped_keys['meta'] ) : ?>

					<div class="form-field">
						<label>Predefined media files meta</label>
						<?php load_template( MAGIC_EX_IM_ABSPATH . 'template-parts/select-export-media-keys.php', false, $args ); ?>
						<p>Select if the meta is meant to store the ID(s) of media files.</p>
					</div>

					<?php endif; ?>

					<input type="hidden" name="magic_item" value="<?php echo esc_attr( $magic_item ); ?>">
					<?php
					do_action( 'magic_ex_before_submit_button' );
					wp_nonce_field( 'magic-ex', 'magic-ex-nonce' );
					submit_button( "Export $magic_item_labels->name" );
					?>
				</form>
			</div>
		</div>

		<?php endif; ?>

		<div class="magic-im-wrapper">

			<h2>Import <?php echo esc_html( $magic_item_labels->name ); ?></h2>

			<div class="form-wrap">
				<form id="magic-im-form" enctype="multipart/form-data" method="post">
					<div class="form-field">
						<label for="magic-im-file">File (.csv)</label>
						<input type="file" name="magic-im-file" id="magic-im-file" accept=".csv" required>
					</div>
					<?php if ( $allow_to_update_items && $allow_to_create_items ) : ?>
					<div class="form-field magic-ex-im-checkbox">
						<input type="checkbox" name="magic-im-skip-new-items" id="magic-im-skip-new-items">
						<label for="magic-im-skip-new-items">Do not create new
							<?php echo esc_html( $magic_item_labels->name ); ?>, only update existing</label>
					</div>
					<div class="form-field magic-ex-im-checkbox">
						<input type="checkbox" name="magic-im-skip-existing-items" id="magic-im-skip-existing-items">
						<label for="magic-im-skip-existing-items">Do not update existing
							<?php echo esc_html( $magic_item_labels->name ); ?>, only create new</label>
					</div>
					<?php else : ?>
					<p>
						<?php
						printf(
							'Only %s %s can be %s, %s is not allowed.',
							$allow_to_update_items ? 'existing' : 'new',
							esc_html( $magic_item_labels->name ),
							$allow_to_update_items ? 'updated' : 'created',
							$allow_to_update_items ? 'creating' : 'updating',
						);
						?>
					</p>
					<?php endif; ?>
					<div class="form-field">
						<label for="magic-im-csv-delimiter">CSV delimiter</label>
						<select name="magic-im-csv-delimiter" id="magic-im-csv-delimiter">
							<option value="," selected>, (comma)</option>
							<option value=";">; (semicolon)</option>
						</select>
					</div>
					<?php if ( 'posts:attachment' === magic_ex_im_get_magic() ) : ?>
					<input type="checkbox" name="magic-im-download-media" checked hidden style="display: none;">
					<?php else : ?>
					<div class="form-field magic-ex-im-checkbox">
						<input type="checkbox" name="magic-im-download-media" id="magic-im-download-media" checked>
						<label for="magic-im-download-media">Download missing media files</label>
					</div>
					<?php endif; ?>
					<div class="form-field magic-ex-im-checkbox">
						<input type="checkbox" name="magic-im-test-mode" id="magic-im-test-mode">
						<label for="magic-im-test-mode">Test mode (preview import result without making any
							changes)</label>
					</div>
					<input type="hidden" name="magic_item" value="<?php echo esc_attr( $magic_item ); ?>">
					<?php
					wp_nonce_field( 'magic-im', 'magic-im-nonce' );
					submit_button( 'Import ' . $magic_item_labels->name );
					?>
				</form>
				<div id="magic-im-progress"></div>
				<ul id="magic-im-notices"></ul>
			</div>
		</div>

	</div>

	<div id="magic-ex-im-footer">
		<p>
			For assistance, cooperation proposals or sponsorship opportunities, feel free to reach out via email
			<a href="mailto:kovalchik888@gmail.com" target="_blank"
				rel="noopener noreferrer">kovalchik888@gmail.com</a>.
		</p>
		<p>
			This plugin with all the features is completely free to use. If you'd like to support its development,
			consider making a donation via
			<a href="https://wise.com/pay/me/romank788" target="_blank">Wise</a>, <a
				href="https://send.monobank.ua/93SXgAPRmB" target="_blank" rel="noopener noreferrer">credit card</a> or
			<a href="#swift-details-wrapper">SWIFT</a>.
		</p>

		<div id="swift-details-wrapper" style="display:none;">
			<div style="display:flex;gap:35px;">
				<div>
					<p><b>SWIFT $</b></p>
					<p><b>IBAN:</b> <code>UA523220010000026207307921237</code></p>
					<p><b>SWIFT/BIC code:</b> <code>UNJSUAUKXXX</code></p>
					<p><b>Receiver:</b> <code>KOVALSKYI ROMAN</code></p>
				</div>
				<div>
					<p><b>SWIFT €</b></p>
					<p><b>IBAN:</b> <code>UA503220010000026202305962431</code></p>
					<p><b>SWIFT/BIC code:</b> <code>UNJSUAUKXXX</code></p>
					<p><b>Receiver:</b> <code>KOVALSKYI ROMAN</code></p>
				</div>
			</div>
		</div>
	</div>

</div>
